Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mumble-voip/mumble.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/macx
diff options
context:
space:
mode:
authorDavide Beatrici <davidebeatrici@gmail.com>2019-04-05 01:57:17 +0300
committerDavide Beatrici <davidebeatrici@gmail.com>2019-04-05 01:57:17 +0300
commit1813fe1af30ee1a953025ddb3017c2faf0f14ccf (patch)
tree4d39f046118a0d4c0b5f3628d89facd97bbe5634 /macx
parentb1f89643e9af3419ad7cb3fc27b1e878aa3defe1 (diff)
macx/scripts/osxdist.py: copy Opus library into App Bundle
The script copies the CELT (dynamic) libraries into the App Bundle, so that they are installed and then loaded by Mumble. This commit adds the Opus library to the list of files to copy, necessary because it is loaded at runtime since e0ee016e5c333dabd2603b01decbe8ef2ae030e2.
Diffstat (limited to 'macx')
-rwxr-xr-xmacx/scripts/osxdist.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/macx/scripts/osxdist.py b/macx/scripts/osxdist.py
index b2e8899fe..c758bb4b9 100755
--- a/macx/scripts/osxdist.py
+++ b/macx/scripts/osxdist.py
@@ -129,12 +129,12 @@ class AppBundle(object):
def copy_codecs(self):
'''
Try to copy the dynamic CELT libraries into the App Bundle.
'''
- print ' * Attempting to copy CELT libraries into App Bundle'
+ print ' * Attempting to copy audio codec libraries into App Bundle'
dst = os.path.join(self.bundle, 'Contents', 'Codecs')
os.makedirs(dst)
- codecs = ('release/libcelt0.0.7.0.dylib', 'release/libcelt0.0.11.0.dylib')
+ codecs = ('release/libcelt0.0.7.0.dylib', 'release/libcelt0.0.11.0.dylib', 'release/libopus.dylib')
for codec in codecs:
if os.path.exists(codec):
shutil.copy(codec, dst)
@@ -311,6 +311,7 @@ def package_client():
'release/Mumble.app/Contents/Plugins/libmanual.dylib',
'release/Mumble.app/Contents/Codecs/libcelt0.0.7.0.dylib',
'release/Mumble.app/Contents/Codecs/libcelt0.0.11.0.dylib',
+ 'release/Mumble.app/Contents/Codecs/libopus.dylib',
'release/Mumble.app/Contents/MacOS/mumble-g15-helper',
'release/Mumble.app/Contents/MacOS/sbcelt-helper',
)
@@ -129,12 +129,12 @@ class AppBundle(object):
def copy_codecs(self):
'''
- Try to copy the dynamic CELT libraries into the App Bundle.
+ Try to copy the dynamic audio codec libraries into the App Bundle.
'''